## $Id: test_contract.py 12591 2015-02-11 10:44:28Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Tests for contracts.
"""
import tempfile
import shutil
from zope.interface.verify import verifyClass, verifyObject
from zope.component import createObject
from zope.component.hooks import setSite
from zope.interface import verify
from waeup.ikoba.customers.interfaces import ICustomerNavigation
from waeup.ikoba.customers.contracts import ContractsContainer

from ikobacustom.pcn.testing import (FunctionalLayer, FunctionalTestCase)
from ikobacustom.pcn.customers.contracts import (
    RONContract,
    ROPContract,
    RPRContract,
    RPCContract,
    )
from ikobacustom.pcn.customers.interfaces import (
    IRONContract,
    IROPContract,
    IRPRContract,
    IRPCContract,
    )


class ContractsContainerTestCase(FunctionalTestCase):

    layer = FunctionalLayer

    def test_interfaces(self):
        verify.verifyClass(IRONContract, RONContract)
        verify.verifyClass(ICustomerNavigation, RONContract)
        verify.verifyObject(IRONContract, RONContract())
        verify.verifyObject(ICustomerNavigation, RONContract())
        verify.verifyObject(IROPContract, ROPContract())
        verify.verifyObject(ICustomerNavigation, ROPContract())
        verify.verifyObject(IRPRContract, RPRContract())
        verify.verifyObject(ICustomerNavigation, RPRContract())
        verify.verifyObject(IRPCContract, RPCContract())
        verify.verifyObject(ICustomerNavigation, RPCContract())
        return

    def test_addContract(self):
        container = ContractsContainer()
        contract1 = createObject(u'waeup.RONContract')
        id1 = contract1.contract_id
        container.addContract(contract1)
        self.assertEqual(container[id1], contract1)
        self.assertRaises(TypeError, container.addContract, object())
        self.assertEqual(contract1.class_name, 'RONContract')

        contract2 = createObject(u'waeup.ROPContract')
        id2 = contract2.contract_id
        container.addContract(contract2)
        self.assertEqual(container[id2], contract2)
        self.assertEqual(contract2.class_name, 'ROPContract')

        contract3 = createObject(u'waeup.RPRContract')
        id3 = contract3.contract_id
        container.addContract(contract3)
        self.assertEqual(container[id3], contract3)
        self.assertEqual(contract3.class_name, 'RPRContract')

        contract4 = createObject(u'waeup.RPCContract')
        id4 = contract4.contract_id
        container.addContract(contract4)
        self.assertEqual(container[id4], contract4)
        self.assertEqual(contract4.class_name, 'RPCContract')
        return
